@@ -38,7 +38,7 @@ protected:
     bool readFromFile(const QString &fileName) override;
     bool writeToFile(const QString &fileName) override;
 
-    Akonadi::Collection rootCollection() const override;
+    Q_REQUIRED_RESULT Akonadi::Collection rootCollection() const override;
 
 private Q_SLOTS:
     void onCollectionFetch(KJob *job);
@@ -48,4 +48,3 @@ private:
     QHash<KJob *, Akonadi::Item> mCurrentItemDeletions;
     KMBox::MBox *mMBox = nullptr;
 };
-
