@@ -10,7 +10,7 @@
 
 using namespace Akonadi;
 
-class FileStore::Job::Private
+class FileStore::JobPrivate
 {
 public:
 };
@@ -22,10 +22,7 @@ FileStore::Job::Job(FileStore::AbstractJobSession *session)
     setAutoDelete(true);
 }
 
-FileStore::Job::~Job()
-{
-    delete d;
-}
+FileStore::Job::~Job() = default;
 
 void FileStore::Job::start()
 {
