@@ -41,16 +41,14 @@ TomboyNotesResource::TomboyNotesResource(const QString &id)
 
     mUploadJobProcessRunning = false;
 
-    mManager = new KIO::AccessManager(this);
-    connect(mManager, &KIO::AccessManager::sslErrors, this, &TomboyNotesResource::onSslError);
+    mManager = new KIO::Integration::AccessManager(this);
+    connect(mManager, &KIO::Integration::AccessManager::sslErrors, this, &TomboyNotesResource::onSslError);
 
     qCDebug(TOMBOYNOTESRESOURCE_LOG) << "Resource started";
     connect(this, &TomboyNotesResource::reloadConfiguration, this, &TomboyNotesResource::slotReloadConfig);
 }
 
-TomboyNotesResource::~TomboyNotesResource()
-{
-}
+TomboyNotesResource::~TomboyNotesResource() = default;
 
 void TomboyNotesResource::retrieveCollections()
 {
